pub enum BlockingMode {
None,
Line,
Block(u32),
}Expand description
A blocking flag when dealing with files
When using crate::syscalls::SYS_OPEN, Bit 0 of flags argument can be:
0 - non-blocking
1 - line buffered
In order to use Block mode, you need to issue syscall_blocking_mode
with the whole range of blocking modes available for usage
Variants
Implementations
Sourceimpl BlockingMode
impl BlockingMode